# schedule-service-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import schedule_service_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import schedule_service_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import schedule_service_client
from schedule_service_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = schedule_service_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with schedule_service_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = schedule_service_client.ScheduleApi(api_client)
    course = 56 # int | 
    semester = 56 # int | 

    try:
        # Get Platoons
        api_response = await api_instance.get_platoons_api_v1_schedule_platoons_get(course, semester)
        print("The response of ScheduleApi->get_platoons_api_v1_schedule_platoons_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ScheduleApi->get_platoons_api_v1_schedule_platoons_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ScheduleApi* | [**get_platoons_api_v1_schedule_platoons_get**](docs/ScheduleApi.md#get_platoons_api_v1_schedule_platoons_get) | **GET** /api/v1/schedule/platoons | Get Platoons
*ScheduleApi* | [**get_schedule_api_v1_schedule_get**](docs/ScheduleApi.md#get_schedule_api_v1_schedule_get) | **GET** /api/v1/schedule/ | Get Schedule
*ScheduleApi* | [**get_weeks_schedule_api_v1_schedule_week_get**](docs/ScheduleApi.md#get_weeks_schedule_api_v1_schedule_week_get) | **GET** /api/v1/schedule/week | Get Weeks Schedule
*WorkbookApi* | [**get_course_workbook_api_v1_workbook_course_get**](docs/WorkbookApi.md#get_course_workbook_api_v1_workbook_course_get) | **GET** /api/v1/workbook/{course} | Get Course Workbook
*WorkbookApi* | [**get_workbooks_api_v1_workbook_get**](docs/WorkbookApi.md#get_workbooks_api_v1_workbook_get) | **GET** /api/v1/workbook/ | Get Workbooks


## Documentation For Models

 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Lesson](docs/Lesson.md)
 - [ScheduleResult](docs/ScheduleResult.md)
 - [Shape](docs/Shape.md)
 - [Subject](docs/Subject.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [WeekSchedule](docs/WeekSchedule.md)
 - [WeekScheduleResult](docs/WeekScheduleResult.md)
 - [WorkbookFile](docs/WorkbookFile.md)
 - [WorksheetSettings](docs/WorksheetSettings.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




